ReadBits

Struct ReadBits 

pub struct ReadBits<R> { /* private fields */ }
Buffered bit-level reader that wraps an io::Read byte stream.

Implementations

Source

impl<R> ReadBits<R>

pub fn new(reader: R) -> Self

Creates a new ReadBits wrapping the given reader.

Source

impl<R> ReadBits<R>
where R: Read,

pub fn read_bit(&mut self) -> Result<bool>

Read one bit from the stream.

Returns Ok(bit) if the bit was read successfully. Returns Err if the reader returned an error on read or if the reader is exhausted.

pub fn read_bits( &mut self, buffer: &mut [u8], bit_offset: usize, bit_len: usize, ) -> Result<usize>

Read bits into the buffer. bit_offset specifies the bit offset in the buffer to read into. All bits before bit_offset will be preserved. bit_len specifies number of bits to read.

Returns number of bits read. It would be the bit_len. Unless reader is exhausted.

Panics

The function will panic if buffer doesn’t fit bits in range bit_offset..bit_offset+bit_len. This means that buffer.len() must be equal or greater than (bit_offset + bit_len + 7) / 8.

Function can also panic if internal reader panics on read.

pub fn read_all_bits( &mut self, buffer: &mut [u8], bit_offset: usize, bit_len: usize, ) -> Result<()>

Reads exactly bit_len bits into buffer starting at bit_offset.

Unlike read_bits, this retries on partial reads and returns an error if the reader is exhausted before all bits are read.