pub struct ReadBits<R> { /* private fields */ }Expand description
Buffered bit-level reader that wraps an io::Read byte stream.
Implementations
Sourceimpl<R> ReadBits<R>where
R: Read,
impl<R> ReadBits<R>where
R: Read,
Sourcepub fn read_bit(&mut self) -> Result<bool>
pub fn read_bit(&mut self) -> Result<bool>
Read one bit from the stream.
Returns Ok(bit) if the bit was read successfully.
Returns Err if the reader returned an error on read or if the reader is exhausted.
Sourcepub fn read_bits(
&mut self,
buffer: &mut [u8],
bit_offset: usize,
bit_len: usize,
) -> Result<usize>
pub fn read_bits( &mut self, buffer: &mut [u8], bit_offset: usize, bit_len: usize, ) -> Result<usize>
Read bits into the buffer.
bit_offset specifies the bit offset in the buffer to read into.
All bits before bit_offset will be preserved.
bit_len specifies number of bits to read.
Returns number of bits read.
It would be the bit_len.
Unless reader is exhausted.
Panics
The function will panic if buffer doesn’t fit bits in range bit_offset..bit_offset+bit_len.
This means that buffer.len() must be equal or greater than (bit_offset + bit_len + 7) / 8.
Function can also panic if internal reader panics on read.