pub struct WriteBits<W> { /* private fields */ }Expand description
Buffered bit-level writer that wraps an io::Write byte stream.
Implementations
Sourceimpl<W> WriteBits<W>where
W: Write,
impl<W> WriteBits<W>where
W: Write,
Sourcepub fn write_bit(&mut self, bit: bool) -> Result<()>
pub fn write_bit(&mut self, bit: bool) -> Result<()>
Write one bit to the stream.
Returns Ok(()) if the bit was written successfully.
Returns Err if the writer returned an error on write or if the writer is exhausted.
Sourcepub fn write_bits(
&mut self,
buffer: &[u8],
bit_offset: usize,
bit_len: usize,
) -> Result<usize>
pub fn write_bits( &mut self, buffer: &[u8], bit_offset: usize, bit_len: usize, ) -> Result<usize>
Write bits from the slice.
bit_offset specifies the bit offset in the buffer.
bit_len specifies number of bits to write.
Returns number of bits written.
It would be the bit_len.
Unless writer is exhausted.
Sourcepub fn write_all_bits(
&mut self,
buffer: &[u8],
bit_offset: usize,
bit_len: usize,
) -> Result<()>
pub fn write_all_bits( &mut self, buffer: &[u8], bit_offset: usize, bit_len: usize, ) -> Result<()>
Writes exactly bit_len bits from buffer starting at bit_offset.
Unlike write_bits, this retries on partial writes
and returns an error if the writer cannot accept all bits.